//
//  RWTMyScene.m
//  SpriteKitLevelSelector
//
//  Created by Main Account on 5/5/14.
//  Copyright (c) 2014 Razeware LLC. All rights reserved.
//

#import "RWTLevelSelectScene.h"
#import "RWTMyScene.h"
#import "RWTViewController.h"

@interface RWTLevelSelectScene()
@property (assign, nonatomic) CGSize imageSize;
@property (weak, nonatomic) RWTViewController *vc;
@end

@implementation RWTLevelSelectScene

static const CGFloat kMargin = 40;

- (id)initWithSize:(CGSize)size vc:(RWTViewController *)vc {
  if (self = [super initWithSize:size]) {
    
    _vc = vc;
    self.physicsWorld.gravity = CGVectorMake(0, 0);
    
    SKSpriteNode *bg = [SKSpriteNode spriteNodeWithImageNamed:@"bg.png"];
    bg.anchorPoint = CGPointZero;
    [self addChild:bg];
    
    self.imageSize = [SKSpriteNode spriteNodeWithImageNamed:@"card_level01"].size;
    CGFloat initialMargin = self.size.width/2;
    CGFloat marginPerImage = kMargin + self.imageSize.width;
    
    _world = [[SKSpriteNode alloc] init];
    _world.size = CGSizeMake(initialMargin*2 + (marginPerImage * 7), self.size.height);
    
    [self addChild:_world];
    
    for(int i = 1; i <= 8; ++i) {
      
      NSString *iconName = [NSString stringWithFormat:@"card_level%02d", i];
      SKSpriteNode *sprite = [SKSpriteNode spriteNodeWithImageNamed:iconName];
      
      sprite.position = CGPointMake(initialMargin + (marginPerImage * (i - 1)), self.size.height/2);
      [_world addChild:sprite];
      
      sprite.physicsBody = [SKPhysicsBody bodyWithRectangleOfSize:sprite.size];
      sprite.physicsBody.collisionBitMask = 0;
      sprite.userData = [NSMutableDictionary dictionaryWithObject:@(i) forKey:@"index"];
      sprite.name = @"cards";
            
    }
    
  }
  return self;
}

- (void)update:(NSTimeInterval)currentTime {
  [self.vc updatePosition];
}

- (void)handleTap:(UITapGestureRecognizer *)recognizer {
  
  CGPoint tapLocation = [recognizer locationInView:self.view];
  tapLocation = [self convertPointFromView:tapLocation];
  
  NSLog(@"Tapped!");
  [self.physicsWorld enumerateBodiesAtPoint:tapLocation usingBlock:^(SKPhysicsBody *body, BOOL *stop) {
    
    SKSpriteNode *sprite = (SKSpriteNode *)body.node;
    
    [self.world enumerateChildNodesWithName:@"cards" usingBlock:^(SKNode *node, BOOL *stop) {
      if (node != sprite) {
        [node runAction:[SKAction fadeAlphaTo:0 duration:0.4]];
      }
    }];
    
    CGPoint newPos = [self convertPoint:sprite.position fromNode:sprite.parent];
    [sprite removeFromParent];
    sprite.position = newPos;
    [self addChild:sprite];
    
    SKAction *scaleAction = [SKAction scaleTo:1.5 duration:0.4];
    scaleAction.timingMode = SKActionTimingEaseInEaseOut;
    
    SKAction *moveAction = [SKAction moveTo:CGPointMake(self.size.width/2, self.size.height/2) duration:0.4];
    moveAction.timingMode = SKActionTimingEaseInEaseOut;
    
    SKAction *groupAction = [SKAction group:@[scaleAction, moveAction]];
    
    [sprite runAction:[SKAction sequence:@[
      groupAction,
      [SKAction waitForDuration:0.5],
      [SKAction runBlock:^{
        NSUInteger levelNum = [sprite.userData[@"index"] unsignedIntegerValue];
        RWTMyScene *myScene = [[RWTMyScene alloc] initWithSize:self.size levelNum:levelNum vc:self.vc];
        SKTransition *reveal = [SKTransition flipHorizontalWithDuration:0.5];
        [self.view presentScene:myScene transition:reveal];
    }]
    ]]];
    
    return;
    
  }];
  
}

- (CGPoint)scrollOffsetForProposedOffset:(CGPoint)offset {

  CGFloat pageWidth = kMargin + self.imageSize.width;
  CGFloat overshoot = fmodf(offset.x, pageWidth);
  
  if (overshoot < pageWidth/2) {
    offset.x -= overshoot;
  } else {
    offset.x += pageWidth - overshoot;
  }
  
  return offset;
}


@end
